let LIST_API = "https://hiit.ria.rocks/videos_api/cdn/com.rstream.crafts";
const searchParams = new URLSearchParams(window.location.search);
let appName = searchParams.get("appname");
let lang = searchParams.get("lang");
if (lang == "ar" || lang == "fa") {
  document.body.classList.add("arabic");
  document.documentElement.setAttribute("dir", "rtl");
}
let collectionData;
let categoryIcons = [
  "./assets/soon.png",
  "./assets/star1.png",
  "./assets/leave.png",
];

let setCategories = [];
let theShortsList = [];
let pageTitle = document.querySelector(".page-title");
pageTitle.innerHTML = languages[lang]
  ? languages[lang]["What's New"]
  : "What's New";
let categoriesContainer = document.querySelector(".categories");
let itemListContainer = document.querySelector(".top-ten-list");
let scrollCheck = true;

const renderCategories = (list) => {
  categoriesContainer.innerHTML = "";
  for (let i = 0; i < list.length; i++) {
    if (list[i].categories == null) continue;
    let singleCategory = createHTMLElement("DIV", "single-category");
    singleCategory.id = `${list[i].collection}-category`;
    let categoryIcon = createHTMLElement("DIV", "category-icon");
    let categoryImg = createHTMLElement("IMG", "category-img");
    if (i <= 2) {
      categoryImg.src = categoryIcons[i];
    } else {
      categoryImg.src = "./assets/watching.png";
    }
    categoryIcon.appendChild(categoryImg);
    let categoryName = createHTMLElement("DIV", "category-name");
    if (i == 0) singleCategory.classList.add("selected");
    categoryName.innerHTML = languages[lang]
      ? languages[lang][list[i].collection]
      : list[i].collection;
    categoryName.dataset.name = list[i].collection;
    singleCategory.append(categoryIcon, categoryName);
    singleCategory.addEventListener("click", () => {
      document.querySelectorAll(".single-category").forEach((element) => {
        element.classList.remove("selected");
      });
      singleCategory.classList.toggle("selected");
      let categoryName =
        singleCategory.querySelector(".category-name").dataset.name;
      const selectedData = collectionData.find(
        (collection) => collection.collection == categoryName
      );

      // document
      //   .getElementById(`${list[i].collection}-firstItem`)
      //   .scrollIntoView({ behavior: "smooth", block: "start" });
      scrollCheck = false;
      setTimeout(() => {
        scrollCheck = true;
      }, 1000);
      scrollToTargetAdjusted(
        document.getElementById(`${list[i].collection}-firstItem`)
      );

      singleCategory.scrollIntoView(true);
    });

    categoriesContainer.appendChild(singleCategory);
  }
};

function scrollToTargetAdjusted(element) {
  // console.log(element);
  var headerOffset = 118;
  var elementPosition = element.getBoundingClientRect().top;
  var offsetPosition = elementPosition + window.pageYOffset - headerOffset;

  window.scrollTo({
    top: offsetPosition,
    behavior: "smooth",
  });
}

const inView = (element) => {
  var top = element.offsetTop - 120;
  var height = element.offsetHeight;

  while (element.offsetParent) {
    element = element.offsetParent;
    top += element.offsetTop;
  }

  return (
    top < window.scrollY + window.innerHeight && top + height > window.scrollY
  );
};
function update() {
  let next = false;
  let sections = itemListContainer.childNodes;
  sections.forEach((section) => {
    let collect = section.dataset.collection;
    const currentCat = document.getElementById(`${collect}-category`);

    if (scrollCheck && currentCat != null) {
      if (inView(section) && !next) {
        currentCat.classList.add("selected");
        currentCat.scrollIntoView(true);
        next = true;
      } else {
        currentCat.classList.remove("selected");
      }
    }
  });
}
window.addEventListener("scroll", update);

const renderList = async (name, list, soon = false, all = false) => {
  let listItemContainer = createHTMLElement("DIV", "list-items-container");
  listItemContainer.id = `${name}-firstItem`;
  listItemContainer.dataset.collection = name;
  let listItemHeading = createHTMLElement(
    "DIV",
    soon ? "list-items-heading no-style" : "list-items-heading"
  );
  // listItemHeading.id = `${name}-firstItem`;
  listItemHeading.dataset.collection = name;
  listItemHeading.innerHTML = soon
    ? ""
    : languages[lang]
    ? languages[lang][name]
    : name;
  listItemContainer.appendChild(listItemHeading);
  for (let i = 0; i < list.length; i++) {
    if (list[i].imgurl == null) continue;
    if (all && i == 1) {
      let shortsContainer = document.createElement("div");
      shortsContainer.className = "shorts-container";
      getShortsList(shortsContainer);
      listItemContainer.append(shortsContainer);
    }
    if (all && i == 3) {
      let storiesContainer = document.createElement("div");
      storiesContainer.className = "stories-container";
      getStoriesList(storiesContainer);
      listItemContainer.append(storiesContainer);
    }
    // if (i == 0 || i == 1 || i == 2) continue;
    let listItem = createHTMLElement("DIV", "list-item");
    let itemContainer = createHTMLElement("DIV", "item-container");
    let videoContainer = createHTMLElement("DIV", "video-container blurred");
    let videoThumbnail = createHTMLElement("IMG");
    videoThumbnail.loading = "lazy";
    videoThumbnail.src = list[i]["imgurl"];
    if (soon && (!searchParams.has("data") || !searchParams.has("datanew"))) {
      videoContainer.addEventListener("click", () => {
        if (reminderIconContainer.dataset.status == "UNSET") {
          deeplink(
            `http://riafy.me/videoNotifyCategory/${JSON.stringify(list[i])}`
          );
        } else {
          deeplink(
            `http://riafy.me/videoRemoveNotifyCategory/${list[i]["category"]}`
          );
        }
      });
    }
    videoContainer.appendChild(videoThumbnail);
    function imgLoaded() {
      videoContainer.classList.remove("blurred");
    }
    if (videoThumbnail.complete) {
      imgLoaded();
    } else {
      videoThumbnail.addEventListener("load", imgLoaded);
    }

    let dateSplit;
    let theDate;
    if (soon) {
      dateSplit = list[i].date.split("/");
      theDate = new Date(`${dateSplit[1]}/${dateSplit[0]}/${dateSplit[2]}`);
    }
    // theDate = new Date(`10/19/2023`);

    let videoTitleContainer = createHTMLElement("DIV", "title-container");
    let videoTitle = createHTMLElement("DIV", "language-text");
    videoTitle.innerHTML = list[i]["category"];
    let reminderIconContainer = createHTMLElement(
      "DIV",
      "reminder-icon-container"
    );
    reminderIconContainer.dataset.category = list[i]["category"];
    reminderIconContainer.dataset.status = "UNSET";
    let reminderIcon = createHTMLElement("IMG", "reminder-icon");
    let reminderIconText = createHTMLElement("DIV", "reminder-text");
    reminderIconText.innerHTML = languages[lang]
      ? languages[lang]["Remind Me"]
      : "Remind Me";
    if (searchParams.has("dark")) {
      reminderIcon.src = "./assets/bell-light.svg";
    } else {
      reminderIcon.src = "./assets/bell.svg";
    }
    reminderIconContainer.append(reminderIcon, reminderIconText);

    reminderIconContainer.addEventListener("click", () => {
      if (reminderIconContainer.dataset.status == "UNSET") {
        deeplink(
          `http://riafy.me/videoNotifyCategory/${JSON.stringify(list[i])}`
        );
      } else {
        deeplink(
          `http://riafy.me/videoRemoveNotifyCategory/${list[i]["category"]}`
        );
      }
    });
    if (soon && checkBeforeDate(theDate)) {
      if (searchParams.has("data") && searchParams.has("datanew")) {
        videoTitleContainer.append(videoTitle);
      } else {
        videoTitleContainer.append(videoTitle, reminderIconContainer);
      }
    } else {
      videoTitleContainer.append(videoTitle);
    }
    let videoDescription = createHTMLElement("DIV", "show-brief");
    videoDescription.innerHTML = list[i]["short description"];
    let videoTags = createHTMLElement("DIV", "show-tags");

    if (soon) {
      if (!checkBeforeDate(theDate)) {
        listItem.addEventListener("click", () => {
          deeplink(`http://riafy.me/videoPlayerCategory/${list[i].category}`);
        });
      } else {
        if (searchParams.has("data") && searchParams.has("datanew")) {
          listItem.addEventListener("click", () => {
            deeplink(`http://riafy.me/videoPlayerCategory/${list[i].category}`);
          });
        }
      }
    } else {
      listItem.addEventListener("click", () => {
        deeplink(`http://riafy.me/videoPlayerCategory/${list[i].category}`);
      });
    }

    let dateContainer;
    if (soon) {
      dateContainer = createHTMLElement("DIV", "date-container");
      let day = createHTMLElement("DIV", "date-day");
      let monthName = createHTMLElement("DIV", "date-month");
      if (parseInt(dateSplit[0]) < 10 && !dateSplit[0].startsWith("0")) {
        day.innerHTML = `0${dateSplit[0]}`;
      } else {
        day.innerHTML = dateSplit[0];
      }
      monthName.innerHTML = theDate.toLocaleString("en-US", {
        month: "short",
      });
      dateContainer.append(monthName, day);
    }
    itemContainer.append(
      videoContainer,
      videoTitleContainer,
      videoDescription,
      videoTags
    );

    if (soon) {
      listItem.append(dateContainer, itemContainer);
    } else {
      listItem.appendChild(itemContainer);
    }

    if (soon && checkBeforeDate(theDate)) {
      listItemContainer.appendChild(listItem);
    } else {
      if (!soon) listItemContainer.appendChild(listItem);
    }
  }

  //observer.observe(listItemContainer);
  itemListContainer.appendChild(listItemContainer);
};

function checkBeforeDate(theDate) {
  let currentDate = new Date();
  if (theDate > currentDate) {
    return true;
  } else {
    return false;
  }
}

const renderShortsList = async (parEl, list) => {
  let shortsHeading = createHTMLElement("div", "shorts-heading");
  shortsHeading.innerHTML = languages[lang]
    ? languages[lang]["Shorts"]
    : "Shorts";
  let shortsList = createHTMLElement("div", "shorts-list");
  list.forEach((shortsCat) => {
    let shortCatContain = createHTMLElement("div", "shorts-cat-container");
    // let shortCatContainImg = createHTMLElement("img", "shorts-container-img");
    // shortCatContainImg.src = shortsCat.imgurl;
    let linearGradient = `linear-gradient(180deg, rgba(255,255,255,0) 47%, rgba(0,0,0,0.47) 100%)`;
    shortCatContain.style.backgroundImage = `${linearGradient}, url("${shortsCat.imgurl}")`;
    let shortCatContainName = createHTMLElement("div", "shorts-category-name");
    shortCatContainName.innerHTML = shortsCat.category;
    shortCatContain.addEventListener("click", () => {
      let passData = {
        appId: appName,
        currentCategory: shortsCat.category,
        fullData: theShortsList,
      };
      deeplink(`http://thecookbk.com/openShorts/${JSON.stringify(passData)}`);
    });

    shortCatContain.append(shortCatContainName);
    shortsList.appendChild(shortCatContain);
  });

  parEl.append(shortsHeading, shortsList);
};
const renderStoriesList = async (parEl, list) => {
  let storiesHeading = createHTMLElement("div", "stories-heading");
  storiesHeading.innerHTML = languages[lang]
    ? languages[lang]["Stories"]
    : "Stories";
  let storiesList = createHTMLElement("div", "stories-list");
  list.forEach((story) => {
    let shortCatContain = createHTMLElement("div", "stories-cat-container");
    shortCatContain.style.backgroundImage = `url("${story.cornerImageUrl}")`;
    let shortCatContainImg = createHTMLElement("img", "stories-icon");
    shortCatContainImg.src = story.iconUrl;
    shortCatContain.style.borderColor = story.borderColor;
    let shortCatContainName = createHTMLElement("div", "stories-name");
    shortCatContainName.innerHTML = story.name;
    shortCatContain.addEventListener("click", () => {
      deeplink(`http://thecookbk.com/storyName/${story.name}`);
    });

    shortCatContain.append(shortCatContainImg, shortCatContainName);
    storiesList.appendChild(shortCatContain);
  });

  parEl.append(storiesHeading, storiesList);
};

const createHTMLElement = (type, className = "", idName = "") => {
  let element = document.createElement(type);
  if (className != "") element.className = className;
  if (idName != "") element.id = idName;
  return element;
};

const getShortsList = async (parEl) => {
  fetch(`https://hiit.ria.rocks/videos_api/cdn/${appName}_shorts?lang=${lang}`)
    .then((response) => {
      return response.json();
    })
    .then(async (result) => {
      theShortsList = result;
      if (result.length == 0) parEl.classList.add("hidden");
      renderShortsList(parEl, result);
    })
    .catch((err) => {
      console.warn("Something went wrong.", err);
    });
};
const getStoriesList = async (parEl) => {
  fetch(
    `https://forking.riafy.in/story-console/get-stories-api.php?page=storyhome&type=home&data=1&appname=${appName}&lang=${lang}`
  )
    .then((response) => {
      return response.json();
    })
    .then(async (result) => {
      let { stories } = result.home;
      console.log(stories);
      if (stories.length == 0) parEl.classList.add("hidden");
      renderStoriesList(parEl, stories);
    })
    .catch((err) => {
      console.warn("Something went wrong.", err);
    });
};

const getVideoList = async (appName) => {
  fetch(
    `https://forking.riafy.in/rstream-festival-collected-api.php?appname=${appName}&lang=${lang}`
  )
    .then((response) => {
      return response.json();
    })
    .then(async (result) => {
      collectionData = result;
      await renderCategories(result);
      itemListContainer.innerHTML = "";

      result.forEach((item, index) => {
        if (index == 0) {
          renderList(item.collection, item.categories, true, false);
        } else if (index == 1) {
          renderList(item.collection, item.categories, false, true);
        } else {
          renderList(item.collection, item.categories, false, false);
        }
      });
      deeplink(`http://riafy.me/loadRemindedCategories`);
    })
    .catch((err) => {
      console.warn("Something went wrong.", err);
    });
};

function updateRemindList(list) {
  setCategories = list;
  let theRemindList = document.querySelectorAll(".reminder-icon-container");

  theRemindList.forEach((element) => {
    if (searchParams.has("dark")) {
      if (setCategories.includes(element.dataset.category)) {
        element.querySelector(".reminder-icon").src = "./assets/done_light.png";
        element.querySelector(".reminder-text").innerHTML = languages[lang]
          ? languages[lang]["Reminder Set"]
          : "Reminder Set";
        element.dataset.status = "SET";
      } else {
        element.querySelector(".reminder-icon").src = "./assets/bell-light.svg";
        element.querySelector(".reminder-text").innerHTML = languages[lang]
          ? languages[lang]["Remind Me"]
          : "Remind Me";
        element.dataset.status = "UNSET";
      }
    } else {
      if (setCategories.includes(element.dataset.category)) {
        element.querySelector(".reminder-icon").src = "./assets/done_dark.png";
        element.querySelector(".reminder-text").innerHTML = languages[lang]
          ? languages[lang]["Reminder Set"]
          : "Reminder Set";
        element.dataset.status = "SET";
      } else {
        element.querySelector(".reminder-icon").src = "./assets/bell.svg";
        element.querySelector(".reminder-text").innerHTML = languages[lang]
          ? languages[lang]["Remind Me"]
          : "Remind Me";
        element.dataset.status = "UNSET";
      }
    }
  });
}
function addDark() {
  var r = document.querySelector(":root");
  r.style.setProperty("--main-bg-color", "#000");
  r.style.setProperty("--second-bg-color", "#1d1d1d");
  r.style.setProperty("--main-text-color", "#fff");
  r.style.setProperty("--select-category-bg-color", "#fff");
  r.style.setProperty("--select-category-text-color", "#000");
  r.style.setProperty("--secondary-text-color", "#bbb");
  r.style.setProperty("--skeleton-loader-main", "#1f1f1f");
  r.style.setProperty("--skeleton-loader-second", "#252525");
}
function addLight() {
  var r = document.querySelector(":root");
  r.style.setProperty("--main-bg-color", "#fff");
  r.style.setProperty("--second-bg-color", "#ddd");
  r.style.setProperty("--main-text-color", "#000");
  r.style.setProperty("--select-category-bg-color", "#000");
  r.style.setProperty("--select-category-text-color", "#fff");
  r.style.setProperty("--secondary-text-color", "#4b4b4b");
  r.style.setProperty("--skeleton-loader-main", "#d0d0d0");
  r.style.setProperty("--skeleton-loader-second", "#d9d9d9");
}
function nightModeSwitch(check = 0) {
  if (check == 1) {
    // to trigger night mode
    addDark();
    return;
  } else if (check == 2) {
    //to trigger day mode
    addLight();
    return;
  }
  if (searchParams.has("iOS")) {
    if (searchParams.has("dark")) {
      addDark();
    }
  } else {
    var now = new Date();
    var hrs = now.getHours();
    var greet;
    if (hrs >= 19 || hrs <= 6) {
      addDark();
    }
  }
}
function deeplink(link) {
  if (window.location.href.indexOf("localhost") == -1) {
    window.location.href = link;
  } else {
    console.log(link);
  }
}
document.addEventListener("DOMContentLoaded", async (event) => {
  if (searchParams.has("dark")) {
    nightModeSwitch(1);
  }

  // categories[0].classList.add("selected");
  // let firstCategory = categories[0].querySelector(".category-name").innerHTML;
  await getVideoList(appName);
});
