class Sharecard extends HTMLElement {
  constructor() {
    super();
    this.attachShadow({ mode: "open" });
    this.shadow = this.shadowRoot;
    this.canvas;
    this.ctx;
    this.newImg;
    this.targetImg;
    this.insideImg;

    this.cardData = {};
    this.shadowRoot.innerHTML = `
        <style>
        * {
            box-sizing: border-box;
            margin: 0;
            padding: 0;
        
            font-family: SF Pro Display, -apple-system, BlinkMacSystemFont, Helvetica Neue,
            Segoe UI, Roboto, Ubuntu, sans-serif;
        }
        
        body,
        .container {
            display: flex;
            justify-content: center;
            align-items: center;
        }
        .container {
            min-height: 100vh;
            width: 100%;
            justify-content: space-around;
        }
        
        button {
            outline: 0;
            border: 0;
            color: #fff;
            background-color: #202025;
            border-radius: 25px;
            padding: 8px 15px;
            font-size: 14px;
            margin-top: 48px;
        }
        
        .card {
            background: #96C291;
            background: -webkit-linear-gradient(to bottom, #DBFF73, #96C291);
            background: linear-gradient(to bottom, #DBFF73, #96C291);
            position: absolute;
        
            border-radius: 12px;
            height: 80vh;
            width: 400px;
            padding: 20px;
        
            display: flex;
            flex-direction: column;
            justify-content: center;
            align-items: center;
        }
        
        .image-container img {
            width: 100%;
            max-width: 200px;
        }
        .image-container {
          margin-bottom: 35px;
        }
        
        .card-bottom {
            display: flex;
            flex-direction: column;
            align-items: center;
        }
        .title {
            text-align: center;
            font-weight: 800;
            font-size: 38px;
            background: -webkit-linear-gradient(to bottom, #202025, #202025);
            background: linear-gradient(to bottom, #202025, #202025);
            background-clip: text;
            -webkit-background-clip: text;
            -webkit-text-fill-color: transparent;
        }
        .sub-title {
            text-align: center;
            font-weight: 500;
            font-size: 20px;
            color: #202025;
            margin: 0 0 20px 0;
        }
        
        @media only screen and (max-width: 600px) {
            .card {
                width: 100%;
                height: 100%;
                border-radius: 0;
                top: 0;
                left: 0;
            }
        }      
        .close-card-comp {
            top: 1rem;
            right: 1rem;
            position: absolute;
            cursor: pointer;
            background-color: grey;
            color: #fff;
            display: flex;
            justify-content: center;
            align-items: center;
            width: 30px;
            height: 30px;
            border-radius: 50%;
            font-size: 1rem;
        }
        </style>
        <div id="theContainer" class="container">
        <div id="theCard" class="card">
            <div class="close-card-comp">X</div>
            <div class="image-container">
            <img class="badge-image" src="./assets/8.png" />
            </div>

            <div class="card-bottom">
            <div class="title">ACHIEVEMENT NAME</div>
            <div class="sub-title">
                ACHIVEMENT DESCRIPTION
            </div>

            <button id="share-button">Share</button>
            </div>
        </div>
        </div>
    `;
  }
  static get observedAttributes() {
    return ["error", "value"];
  }

  passEvent = new CustomEvent("pass", {
    detail: {
      deleteComp: true,
    },
  });

  async connectedCallback() {
    // await this.getJsonData();
    // console.log(this.cardData);
    if (this.hasAttribute("ria-card-data")) {
      let newData = this.getAttribute("ria-card-data");
      this.cardData = JSON.parse(newData);
    }
    let card = this.shadowRoot.querySelector(".card");
    let title = this.shadowRoot.querySelector(".title");
    let badgeImage = this.shadowRoot.querySelector(".badge-image");
    let subTitle = this.shadowRoot.querySelector(".sub-title");
    let shareButton = this.shadowRoot.querySelector("#share-button");
    let closeButton = this.shadowRoot.querySelector(".close-card-comp");
    title.innerHTML = this.cardData.achievementName;
    badgeImage.src = this.cardData.badgeImage;
    subTitle.innerHTML = this.cardData.achivementDescription;
    shareButton.innerHTML = this.cardData.buttonText;
    if (
      this.cardData.cardBackground &&
      this.cardData.cardBackground.length != 0
    ) {
      if (this.cardData.cardBackground.length == 1)
        card.style.background = this.cardData.cardBackground[0];
      if (this.cardData.cardBackground.length == 2) {
        card.style.background = `linear-gradient(to bottom, ${this.cardData.cardBackground[0]}, ${this.cardData.cardBackground[1]})`;
      }
    }
    if (
      this.cardData.titleBackground &&
      this.cardData.titleBackground.length != 0
    ) {
      if (this.cardData.titleBackground.length == 1) {
        title.style.background = this.cardData.titleBackground[0];
        title.style.backgroundClip = `text`;
        title.style.webkitBackgroundClip = `text`;
        title.style.webkitTextFillColor = `transparent`;
      }

      if (this.cardData.titleBackground.length == 2) {
        title.style.background = `linear-gradient(to bottom, ${this.cardData.titleBackground[0]}, ${this.cardData.titleBackground[1]})`;
        title.style.backgroundClip = `text`;
        title.style.webkitBackgroundClip = `text`;
        title.style.webkitTextFillColor = `transparent`;
      }
    }

    this.canvas = document.createElement("canvas");
    this.ctx = this.canvas.getContext("2d");
    this.newImg = document.createElement("img");
    // this.newImg.crossOrigin = "anonymous";
    this.newImg.addEventListener("load", (e) => this.onNewImageLoad(e));
    this.targetImg = document.createElement("img");
    this.targetImg.crossOrigin = "anonymous";
    this.targetImg.style.display = "none";
    this.shadowRoot.querySelector("#theContainer").appendChild(this.targetImg);
    this.insideImg = new Image();
    // this.insideImg.crossOrigin = "anonymous";
    this.insideImg.addEventListener("load", () => this.insideImgLoad());

    shareButton.addEventListener("click", () => this.shareTrigger());
    closeButton.addEventListener("click", () => {
      document.dispatchEvent(this.passEvent);
    });
  }
  async downloadImage(imageSrc, nameOfDownload = "comp-one.png") {
    // const response = await fetch(imageSrc);
    // const blobImage = await response.blob();
    // const href = URL.createObjectURL(blobImage);

    // const anchorElement = document.createElement("a");
    // anchorElement.href = href;
    // anchorElement.download = nameOfDownload;

    // document.body.appendChild(anchorElement);
    // anchorElement.click();

    // document.body.removeChild(anchorElement);
    // window.URL.revokeObjectURL(href);
    // 1. Fetch the image from the source URL
    const response = await fetch(imageSrc);
    const blobImage = await response.blob();

    // 2. Convert the blob into Base64
    var reader = new FileReader();
    reader.readAsDataURL(blobImage);
    reader.onloadend = function () {
      var base64data = reader.result;
      console.log(base64data);
      console.log(base64data.length);
      console.log(base64data.split(",")[1]);
      if (window.webkit != undefined) {
        if (window.webkit.messageHandlers.appInterface != undefined) {
          window.webkit.messageHandlers.fileHandler.postMessage(base64data);
        }
      }
      if (window.appInterface != undefined) {
        window.appInterface.postMessage(base64data);
      }
    };

    reader.onerror = function (error) {
      console.error("Error reading blob:", error);
    };

    console.log("Blob size:", blobImage.size);
    console.log("Blob type:", blobImage.type);
  }
  scaleIt(source, scaleFactor) {
    var c = document.createElement("canvas");
    var ctx = c.getContext("2d");
    var w = source.width * scaleFactor;
    var h = source.height * scaleFactor;
    c.width = w;
    c.height = h;
    ctx.drawImage(source, 0, 0, w, h);
    return c;
  }
  insideImgLoad() {
    var c1 = this.scaleIt(this.insideImg, 1);

    let fitRatio = this.calculateAspectRatioFit(
      this.insideImg.width,
      this.insideImg.height,
      this.canvas.width / 2,
      this.canvas.height / 2
    );
    console.log(fitRatio);
    this.ctx.drawImage(c1, 200, 380, fitRatio.width, fitRatio.height);

    this.targetImg.src = this.canvas.toDataURL();
    this.downloadImage(this.targetImg.src);
  }
  async getJsonData() {
    const response = await fetch("./theData.json");
    const data = await response.json();
    this.cardData = data;
  }
  onNewImageLoad(e) {
    console.log(e.target);
    var c1 = this.scaleIt(e.target, 2);
    console.log(this.canvas);
    this.canvas.width = c1.width;
    this.canvas.height = c1.height;
    this.ctx.drawImage(c1, 0, 0);

    this.insideImg.src = this.cardData.badgeImage;
  }
  shareTrigger() {
    this.canvas.width = 400;
    this.canvas.height = 735;

    this.newImg.src =
      "data:image/svg+xml," +
      encodeURIComponent(
        `<svg height="735" width="400" xmlns="http://www.w3.org/2000/svg" > 
        <style>
        * {
        box-sizing: border-box;
        margin: 0;
        padding: 0;
      
        font-family: SF Pro Display, -apple-system, BlinkMacSystemFont, Helvetica Neue,
        Segoe UI, Roboto, Ubuntu, sans-serif;
      }
      button {
        opacity: 0;
        outline: 0;
        border: 0;
        color: #fff;
        background-color: #bebebe70;
        border-radius: 25px;
        padding: 8px 15px;
        font-size: 14px;
      }

      .image-container img {
          width: 100%;
          max-width: 200px;
      }
      .image-container {
        margin-bottom: 35px;
      }
      
      .card {
        background: #0F1D28;
        background: -webkit-linear-gradient(to bottom, #DBFF73, #96C291);
        background: linear-gradient(to bottom, #DBFF73, #96C291);
        ${
          this.cardData.cardBackground &&
          this.cardData.cardBackground.length == 2
            ? `background: linear-gradient(to bottom, ${this.cardData.cardBackground[0]}, ${this.cardData.cardBackground[1]});`
            : ""
        }
        ${
          this.cardData.cardBackground &&
          this.cardData.cardBackground.length == 1
            ? `background: ${this.cardData.cardBackground[0]};`
            : ""
        }
      
        border-radius: 12px;
        height: 100vh;
        width: 400px;
        padding: 20px;
      
        display: grid;
        place-items: center;
        align-content: center;
      }
      .card-bottom {
        display: flex;
        flex-direction: column;
        align-items: center;
        margin-top: 10.5rem;
      }
      .title {
        text-align: center;
        font-weight: 800;
        font-size: 38px;
        background: -webkit-linear-gradient(to bottom, #202025, #202025);
        background: linear-gradient(to bottom, #202025, #202025);
        ${
          this.cardData.titleBackground &&
          this.cardData.titleBackground.length == 2
            ? `background: linear-gradient(to bottom, ${this.cardData.titleBackground[0]}, ${this.cardData.titleBackground[1]});`
            : ""
        }
        ${
          this.cardData.titleBackground &&
          this.cardData.titleBackground.length == 1
            ? `background: ${this.cardData.titleBackground[0]};`
            : ""
        }
        background-clip: text;
        -webkit-background-clip: text;
        -webkit-text-fill-color: transparent;
      }
      .sub-title {
        text-align: center;
        font-weight: 500;
        font-size: 20px;
        color: #202025;
        margin: 0 0 20px 0;
      }
        </style>
        <foreignObject width="400" height="735">
          <div xmlns="http://www.w3.org/1999/xhtml">
            <div id="theCard" class="card">
              <div class="image-container">
                <img src="${this.cardData.badgeImage}" />
              </div>
  
              <div class="card-bottom">
                <div class="title">${this.cardData.achievementName}</div>
                  <div class="sub-title">
                    ${this.cardData.achivementDescription}
                  </div>
              </div>
            </div>
          </div>
        </foreignObject>
        </svg>`
      );
  }

  calculateAspectRatioFit(srcWidth, srcHeight, maxWidth, maxHeight) {
    var ratio = Math.min(maxWidth / srcWidth, maxHeight / srcHeight);
    return { width: srcWidth * ratio, height: srcHeight * ratio };
  }
}

customElements.define("ria-app-sharecard", Sharecard);
